/**
 * 项目：旅游路线
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.components;

import cn.dev33.satoken.stp.StpInterface;
import jakarta.annotation.Resource;
import com.xwd.travel.server.domain.User;
import com.xwd.travel.server.service.UserService;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * 自定义权限加载接口实现类
 */
@Component    // 保证此类被 SpringBoot 扫描，完成 Sa-Token 的自定义权限验证扩展
public class StpInterfaceImpl implements StpInterface {

    @Resource
    private UserService userService;

    /**
     * 返回一个账号所拥有的权限码集合
     */
    @Override
    public List<String> getPermissionList(Object loginId, String loginType) {
        User user = userService.selectByUsername((String)loginId);
        List<String> auths = new ArrayList<>();
        user.getRoleList().forEach(role -> role.getAuthorityList().forEach(authority -> auths.add(authority.getName())));
        return auths;
    }

    /**
     * 返回一个账号所拥有的角色标识集合 (权限与角色可分开校验)
     */
    @Override
    public List<String> getRoleList(Object loginId, String loginType) {
        User user = userService.selectByUsername((String)loginId);
        List<String> roles = new ArrayList<>();
        user.getRoleList().forEach(role -> roles.add(role.getName()));
        return roles;
    }

}
