/**
 * 项目：旅游路线
 * 模型分组：服务管理
 * 模型名称：旅游文章图片表
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.domain;

import java.io.Serializable;

import com.xwd.travel.server.rest.res.ApiCode;
import lombok.*;
import java.util.List;

import com.baomidou.mybatisplus.annotation.*;

import io.swagger.v3.oas.annotations.media.Schema;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonProperty;

import com.xwd.travel.server.base.BaseDomain;
import com.xwd.travel.server.domain.ArticleInfo;
import com.xwd.travel.server.domain.ArticleDetail;

@Data
@Builder(builderMethodName = "newBuilder")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@TableName("`pms_article_image`")
@Schema(name = "ArticleImage", description = "旅游文章图片表")
public class ArticleImage extends BaseDomain {
    /**
     * Id
     */
    @TableId(value = "id", type = IdType.AUTO)
    @Schema(description = "Id", nullable = false)
    private Long id;
    /**
     * 文章id
     */
    @TableField(value = "article_id")
    @Schema(description = "文章id", nullable = false)
    private Long articleId;
    /**
     * 文章id
     */
    @Schema(description = "文章id")
    @TableField(exist = false)
    private ArticleInfo article;
    /**
     * 文章详情id
     */
    @TableField(value = "article_detail_id")
    @Schema(description = "文章详情id", nullable = false)
    private Long articleDetailId;
    /**
     * 文章详情id
     */
    @Schema(description = "文章详情id")
    @TableField(exist = false)
    private ArticleDetail articleDetail;
    /**
     * 图片地址
     */
    @TableField(value = "image_url")
    @Schema(description = "图片地址")
    private String imageUrl;
    /**
     * 操作人Id
     */
    @TableField(value = "editor_id")
    @Schema(description = "操作人Id", nullable = false)
    private Long editorId;
    /**
     * 操作人
     */
    @TableField(value = "editor_name")
    @Schema(description = "操作人", nullable = false)
    private String editorName;
    /**
     * 创建时间
     */
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", nullable = false)
    private java.util.Date createTime;
    /**
     * 更新时间
     */
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间", nullable = false)
    private java.util.Date updateTime;

    /**
     * 设置默认值
     */
    @Override
    public ArticleImage setDefault() {
        if (this.getEditorId() == null) {
            this.setEditorId(1L);
        }
        if (this.getEditorName() == null) {
            this.setEditorName("admin");
        }
        if (this.getCreateTime() == null) {
            this.setCreateTime(new java.util.Date());
        }
        if (this.getUpdateTime() == null) {
            this.setUpdateTime(new java.util.Date());
        }
        return this;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate(boolean throwException) {
        if (this.getArticleId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "文章id不能为空！");
            }
            return false;
        }
        if (this.getArticleDetailId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "文章详情id不能为空！");
            }
            return false;
        }
        if (this.getEditorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人Id不能为空！");
            }
            return false;
        }
        if (this.getEditorName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人不能为空！");
            }
            return false;
        }
        return true;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate() {
        return this.validate(false);
    }

}
