/**
 * 项目：旅游路线
 * 模型分组：服务管理
 * 模型名称：联系方式
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.domain;

import java.io.Serializable;

import com.xwd.travel.server.rest.res.ApiCode;
import lombok.*;
import java.util.List;

import com.baomidou.mybatisplus.annotation.*;

import io.swagger.v3.oas.annotations.media.Schema;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonProperty;

import com.xwd.travel.server.base.BaseDomain;

@Data
@Builder(builderMethodName = "newBuilder")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@TableName("`pms_contact_info`")
@Schema(name = "ContactInfo", description = "联系方式")
public class ContactInfo extends BaseDomain {
    /**
     * Id
     */
    @TableId(value = "id", type = IdType.AUTO)
    @Schema(description = "Id", nullable = false)
    private Long id;
    /**
     * 联系人姓名
     */
    @TableField(value = "contact_name")
    @Schema(description = "联系人姓名", nullable = false)
    private String contactName;
    /**
     * 二维码地址
     */
    @TableField(value = "contact_url")
    @Schema(description = "二维码地址", nullable = false)
    private String contactUrl;
    /**
     * 手机号码
     */
    @TableField(value = "contact_phone")
    @Schema(description = "手机号码", nullable = false)
    private String contactPhone;
    /**
     * 操作人Id
     */
    @TableField(value = "editor_id")
    @Schema(description = "操作人Id", nullable = false)
    private Long editorId;
    /**
     * 操作人
     */
    @TableField(value = "editor_name")
    @Schema(description = "操作人", nullable = false)
    private String editorName;
    /**
     * 创建时间
     */
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", nullable = false)
    private java.util.Date createTime;
    /**
     * 更新时间
     */
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间", nullable = false)
    private java.util.Date updateTime;

    /**
     * 设置默认值
     */
    @Override
    public ContactInfo setDefault() {
        if (this.getEditorId() == null) {
            this.setEditorId(1L);
        }
        if (this.getEditorName() == null) {
            this.setEditorName("admin");
        }
        if (this.getCreateTime() == null) {
            this.setCreateTime(new java.util.Date());
        }
        if (this.getUpdateTime() == null) {
            this.setUpdateTime(new java.util.Date());
        }
        return this;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate(boolean throwException) {
        if (this.getContactName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "联系人姓名不能为空！");
            }
            return false;
        }
        if (this.getContactUrl() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "二维码地址不能为空！");
            }
            return false;
        }
        if (this.getContactPhone() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "手机号码不能为空！");
            }
            return false;
        }
        if (this.getEditorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人Id不能为空！");
            }
            return false;
        }
        if (this.getEditorName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人不能为空！");
            }
            return false;
        }
        return true;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate() {
        return this.validate(false);
    }

}
