/**
 * 项目：旅游路线
 * 模型分组：服务管理
 * 模型名称：旅游文章表
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.travel.server.base.BaseParam;
import com.xwd.travel.server.domain.ArticleInfo;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class ArticleInfoParam extends BaseParam<ArticleInfo> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 文章标题
     */
    @Parameter(description = "文章标题")
    private String articleTitle;
    /**
     * 图片地址
     */
    @Parameter(description = "图片地址")
    private String image;
    /**
     * 是否推荐，0否，1是
     */
    @Parameter(description = "是否推荐，0否，1是")
    private Long isRecommend;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ArticleInfo> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ArticleInfo> toQueryWrapper(String columnPrefix) {
        QueryWrapper<ArticleInfo> wrapper = Wrappers.<ArticleInfo>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        if (this.getArticleTitle() != null) {
            if (this.getArticleTitle().startsWith("%") && this.getArticleTitle().endsWith("%")) {
                wrapper.like(columnPrefix + "article_title", this.getArticleTitle().substring(1, this.getArticleTitle().length() - 1));
            } else if (this.getArticleTitle().startsWith("%") && !this.getArticleTitle().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "article_title", this.getArticleTitle().substring(1));
            } else if (this.getArticleTitle().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "article_title", this.getArticleTitle().substring(0, this.getArticleTitle().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "article_title", this.getArticleTitle());
            }
        }
        if (this.getImage() != null) {
            if (this.getImage().startsWith("%") && this.getImage().endsWith("%")) {
                wrapper.like(columnPrefix + "image", this.getImage().substring(1, this.getImage().length() - 1));
            } else if (this.getImage().startsWith("%") && !this.getImage().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "image", this.getImage().substring(1));
            } else if (this.getImage().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "image", this.getImage().substring(0, this.getImage().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "image", this.getImage());
            }
        }
        wrapper.eq(this.getIsRecommend() != null, columnPrefix + "is_recommend", this.getIsRecommend());
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
