/**
 * 项目：旅游路线
 * 模型分组：服务管理
 * 模型名称：联系方式
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.travel.server.base.BaseParam;
import com.xwd.travel.server.domain.ContactInfo;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class ContactInfoParam extends BaseParam<ContactInfo> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 联系人姓名
     */
    @Parameter(description = "联系人姓名")
    private String contactName;
    /**
     * 二维码地址
     */
    @Parameter(description = "二维码地址")
    private String contactUrl;
    /**
     * 手机号码
     */
    @Parameter(description = "手机号码")
    private String contactPhone;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ContactInfo> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ContactInfo> toQueryWrapper(String columnPrefix) {
        QueryWrapper<ContactInfo> wrapper = Wrappers.<ContactInfo>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        if (this.getContactName() != null) {
            if (this.getContactName().startsWith("%") && this.getContactName().endsWith("%")) {
                wrapper.like(columnPrefix + "contact_name", this.getContactName().substring(1, this.getContactName().length() - 1));
            } else if (this.getContactName().startsWith("%") && !this.getContactName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "contact_name", this.getContactName().substring(1));
            } else if (this.getContactName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "contact_name", this.getContactName().substring(0, this.getContactName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "contact_name", this.getContactName());
            }
        }
        if (this.getContactUrl() != null) {
            if (this.getContactUrl().startsWith("%") && this.getContactUrl().endsWith("%")) {
                wrapper.like(columnPrefix + "contact_url", this.getContactUrl().substring(1, this.getContactUrl().length() - 1));
            } else if (this.getContactUrl().startsWith("%") && !this.getContactUrl().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "contact_url", this.getContactUrl().substring(1));
            } else if (this.getContactUrl().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "contact_url", this.getContactUrl().substring(0, this.getContactUrl().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "contact_url", this.getContactUrl());
            }
        }
        if (this.getContactPhone() != null) {
            if (this.getContactPhone().startsWith("%") && this.getContactPhone().endsWith("%")) {
                wrapper.like(columnPrefix + "contact_phone", this.getContactPhone().substring(1, this.getContactPhone().length() - 1));
            } else if (this.getContactPhone().startsWith("%") && !this.getContactPhone().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "contact_phone", this.getContactPhone().substring(1));
            } else if (this.getContactPhone().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "contact_phone", this.getContactPhone().substring(0, this.getContactPhone().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "contact_phone", this.getContactPhone());
            }
        }
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
