/**
 * 项目：旅游路线
 * 模型分组：系统管理
 * 模型名称：角色表
 * @Author: xiongwei
 * @Date: 2024-01-30 09:42:00
 */

package com.xwd.travel.server.service.impl;

import java.io.Serializable;
import java.util.List;
import java.util.ArrayList;
import java.util.Collection;

import jakarta.annotation.Resource;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.travel.server.service.RoleService;
import com.xwd.travel.server.repository.RoleMapper;
import com.xwd.travel.server.repository.base.RoleBaseMapper;
import com.xwd.travel.server.domain.Role;
import com.xwd.travel.server.rest.req.RoleParam;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.travel.server.domain.RoleAuthority;
import com.xwd.travel.server.domain.Authority;
import com.xwd.travel.server.service.RoleAuthorityService;

@Service
public class RoleServiceImpl extends ServiceImpl<RoleMapper, Role> implements RoleService {
    @Resource
    private RoleAuthorityService roleAuthorityService;

    @Override
    public int updateAllFieldsById(Role entity) {
        return this.getBaseMapper().updateAllFieldsById(entity);
    }

    /**
     * 批量插入
     *
     * @param entityList ignore
     * @param batchSize  ignore
     * @return ignore
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveBatch(Collection<Role> entityList, int batchSize) {
        String sqlStatement = SqlHelper.getSqlStatement(RoleBaseMapper.class, SqlMethod.INSERT_ONE);
        return executeBatch(entityList, batchSize, (sqlSession, entity) -> sqlSession.insert(sqlStatement, entity));
    }

    @Override
    public boolean remove(Wrapper<Role> queryWrapper) {
        return this.getBaseMapper().deleteByQuery(queryWrapper) > 0;
    }


    @Override
    public boolean save(Role entity) {
        boolean flag = super.save(entity);
        if (!entity.getAuthorityList().isEmpty()) {
            List<RoleAuthority> roleAuthorities = new ArrayList<>();
            for (Authority authority : entity.getAuthorityList()) {
                RoleAuthority roleAuthority = new RoleAuthority();
                roleAuthority.setRoleId(entity.getId());
                roleAuthority.setAuthorityId(authority.getId());
                roleAuthorities.add(roleAuthority);
            }
            this.roleAuthorityService.saveBatch(roleAuthorities);
        }
        return flag;
    }

    /**
     * 更新权限
     *
     * @param entity 要更新的对象
     * @return 更新后的对象
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public Role updateAuthority(Role entity) {
        this.baseMapper.updateById(entity);
        if (!entity.getAuthorityList().isEmpty()) {
            this.roleAuthorityService.remove(Wrappers.<RoleAuthority>query().eq("role_id", entity.getId()));

            List<RoleAuthority> roleAuthorities = new ArrayList<>();
            for (Authority authority : entity.getAuthorityList()) {
                RoleAuthority roleAuthority = new RoleAuthority();
                roleAuthority.setRoleId(entity.getId());
                roleAuthority.setAuthorityId(authority.getId());
                roleAuthorities.add(roleAuthority);
            }
            this.roleAuthorityService.saveBatch(roleAuthorities);
        }
        return this.getById(entity.getId());
    }
}
