drop table if exists `pms_travel_info`;
create table `pms_travel_info`
(
  `id` int(11) auto_increment not null comment 'Id',
  `info` text not null comment '须知内容',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='旅游须知';

drop table if exists `pms_contact_info`;
create table `pms_contact_info`
(
  `id` int(11) auto_increment not null comment 'Id',
  `contact_name` varchar(255) not null comment '联系人姓名',
  `contact_url` varchar(255) not null comment '二维码地址',
  `contact_phone` varchar(255) not null comment '手机号码',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='联系方式';

drop table if exists `pms_article_info`;
create table `pms_article_info`
(
  `id` int(11) auto_increment not null comment 'Id',
  `article_title` varchar(255) not null comment '文章标题',
  `image` varchar(255) null comment '图片地址',
  `is_recommend` int(11) not null default 0 comment '是否推荐，0否，1是',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='旅游文章表';

drop table if exists `pms_article_detail`;
create table `pms_article_detail`
(
  `id` int(11) auto_increment not null comment 'Id',
  `article_id` int(11) not null comment '文章id',
  `article_title` varchar(255) not null comment '文章标题',
  `article_type` int(11) not null default 0 comment '文章类型，0 PDF,1图片，2普通富文本',
  `pdf_url` varchar(255) null comment 'pdf存储地址',
  `image` varchar(255) null comment '图片地址',
  `article_content` text not null comment '文章内容',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='旅游文章详情表';

drop table if exists `pms_article_image`;
create table `pms_article_image`
(
  `id` int(11) auto_increment not null comment 'Id',
  `article_id` int(11) not null comment '文章id',
  `article_detail_id` int(11) not null comment '文章详情id',
  `image_url` varchar(255) null comment '图片地址',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='旅游文章图片表';

drop table if exists `sys_message`;
create table `sys_message`
(
  `id` int(11) auto_increment not null comment 'Id',
  `user_id` varchar(128) not null comment '用户Id',
  `msg_type` varchar(50) not null default 'NOTIFICATION' comment '消息类型 [NOTIFICATION.通知 WARNING.告警]',
  `module` varchar(255) not null comment '所属模块',
  `content` text null comment '操作内容',
  `relate_id` int(11) null comment '相关Id',
  `state` varchar(50) not null default 'NO' comment '状态 [YES.是 NO.否]',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='通知告警表';

drop table if exists `sys_setting`;
create table `sys_setting`
(
  `id` int(11) auto_increment not null comment 'Id',
  `name` varchar(128) not null comment '名称',
  `code` varchar(128) not null comment '代码',
  `value` text not null comment '值',
  `remark` varchar(255) null comment '说明',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP comment '更新时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='配置表';

drop table if exists `sys_operation_log`;
create table `sys_operation_log`
(
  `id` int(11) auto_increment not null comment 'Id',
  `log_type` varchar(128) not null comment '日志类型',
  `module` varchar(255) not null comment '所属模块',
  `operation_type` varchar(128) not null comment '操作类型',
  `content` text null comment '操作内容',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP comment '创建时间',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='操作日志表';

drop table if exists `sys_role`;
create table `sys_role`
(
  `id` int(11) auto_increment not null comment 'Id',
  `name` varchar(255) not null comment '名称',
  `remark` varchar(255) null comment '备注',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP,
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='角色表';

drop table if exists `sys_user`;
create table `sys_user`
(
  `id` int(11) auto_increment not null comment 'Id',
  `username` varchar(255) not null comment '用户名',
  `im_user_id` varchar(255) null comment '腾讯云im中的uerId',
  `open_id` varchar(255) null comment '微信open_id',
  `user_type` varchar(50) not null default 'ADMIN' comment '用户类型 [PATIENT.患者 DOCTOR.医生 ADMIN.平台]',
  `register_source` varchar(50) not null default 'PLATFORM' comment '注册来源 [WX.微信 PLATFORM.平台]',
  `obj_id` int(11) null comment '关联对象(doctor_info、user_info)',
  `delete_status` varchar(50) not null default 'NO' comment '是否删除 [YES.是 NO.否]',
  `password` varchar(255) null comment '密码',
  `real_name` varchar(255) null comment '姓名',
  `phone` varchar(32) null comment '手机号',
  `avatar` varchar(255) null comment '头像',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP,
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='用户表';

drop table if exists `sys_user_role`;
create table `sys_user_role`
(
  `id` int(11) auto_increment not null comment 'Id',
  `user_id` int(11) not null comment '用户Id',
  `role_id` int(11) not null comment '角色Id',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='用户角色关系表';

drop table if exists `sys_authority`;
create table `sys_authority`
(
  `id` int(11) auto_increment not null comment 'Id',
  `authority_id` int(11) not null default 0 comment '父级Id',
  `type` varchar(50) not null default 'MENU' comment '权限类型 [DIR.目录 MENU.菜单 BUTTON.按钮]',
  `name` varchar(255) not null comment '名称',
  `path` varchar(255) null comment '路径',
  `redirect` varchar(255) null comment '重定向路径',
  `frame_src` varchar(255) null comment '内嵌Url',
  `keep_alive` boolean not null default true comment '是否缓存',
  `hidden` boolean not null default false comment '是否隐藏',
  `component` varchar(255) null comment '页面组件',
  `title` varchar(255) not null comment '标题',
  `icon` varchar(255) null comment '图标',
  `sort_order` int(11) not null default 0 comment '序号',
  `editor_id` int(11) not null default 1 comment '操作人Id',
  `editor_name` varchar(255) not null default 'admin' comment '操作人',
  `create_time` datetime not null default CURRENT_TIMESTAMP,
  `update_time` datetime not null default CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='权限表';

drop table if exists `sys_role_authority`;
create table `sys_role_authority`
(
  `id` int(11) auto_increment not null comment 'Id',
  `role_id` int(11) not null comment 'sys_role.id',
  `authority_id` int(11) not null comment 'sys_authority.id',
  primary key (`id`)
) engine=InnoDB auto_increment=1 default charset=utf8mb4 collate=utf8mb4_general_ci comment='角色权限对应表';



create index ix_message_msg_type on `sys_message` (`msg_type`);
create index ix_message_editor_id_create_time on `sys_message` (`editor_id`, `create_time`);


create unique index ix_setting_code on `sys_setting` (`code`);


create index ix_operation_log_create_time on `sys_operation_log` (`create_time`);


create unique index ix_role_name on `sys_role` (`name`);


create unique index ix_user_username on `sys_user` (`username`);
create index ix_user_user_type on `sys_user` (`user_type`);


create unique index ix_authority_name on `sys_authority` (`name`);
create index ix_authority_authority_id on `sys_authority` (`authority_id`);


create index ix_role_authority_role_id on `sys_role_authority` (`role_id`);
create index ix_role_authority_authority_id on `sys_role_authority` (`authority_id`);

